#!/bin/sh

dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"...Attendere prego, caricamento cache..."

/opt/kmplayer/bin/kmplayer -cache 8192 -fs $(youtube-dl --format=5 -g http://www.youtube.com/watch?v=bnKDv2ELw0Y)
